# Monkey Testing

- We can't change the vertical axis like in the first method which makes it had to visually filterout noise

## Niceties

- be able to quit early (cancel batch curve fit process) if figure we made a mistake (settings or preset selction). Right now we have to quit 10ish hits time 3ish peaks (quit 30 times) in order to "cancel". Even there, it is not a cancel it writes full report with dummy inputs...
